@@ -1,7 +1,7 @@
 #[macro_use]
 extern crate clap;
 
-use clap::App;
+use clap::{App, AppSettings, Arg, SubCommand};
 use miette::{bail, IntoDiagnostic, Result, WrapErr};
 use std::convert::TryFrom;
 
@@ -11,10 +11,12 @@ use parol::{
     generate_parser_source, generate_tree_layout, generate_user_trait_source, parse,
     render_par_string, try_format, GrammarConfig, ParolGrammar, MAX_K,
 };
-use std::fs;
+use std::{env, fs};
 
 static VERSION: &str = env!("CARGO_PKG_VERSION");
 
+mod tools;
+
 // To rebuild the parser sources from scratch use the command build_parsers.ps1
 
 fn main() -> Result<()> {
@@ -24,7 +26,43 @@ fn main() -> Result<()> {
     trace!("env logger started");
 
     let yaml = load_yaml!("arguments.yml");
-    let config = App::from_yaml(yaml).version(VERSION).get_matches();
+    let config = App::from_yaml(yaml)
+        /*
+         * We want all our "tools" to be registered as subcommands.
+         *
+         * Doing this allows `clap` to give better help and error messages
+         * then if we used AppSettings::AllowExternalSubcommands
+         */
+        .subcommands(tools::names().map(|name| {
+            /*
+             * For now, our subcommands have no names or descriptions
+             *
+             * They all accept infinite args (clap makes no attempt to validate things here).
+             */
+            SubCommand::with_name(name).arg(Arg::with_name("args").index(1).multiple(true))
+        }))
+        // Only invoke tools if they come first, to avoid ambiguity with main binary
+        .setting(AppSettings::ArgsNegateSubcommands)
+        .version(VERSION)
+        .get_matches();
+
+    if let (subcommand_name, Some(sub_matches)) = config.subcommand() {
+        let mut ext_args: Vec<&str> = sub_matches
+            .values_of("args")
+            .map_or_else(Vec::default, |args| args.collect());
+        /*
+         * All of the tools were originally written using `env::args()` meaning they expect tool name to be
+         * first.
+         *
+         * Therefore they expect first argument at index 1 instead of zero.
+         * Fake a command name to avoid changing all the indices
+         */
+        ext_args.insert(0, subcommand_name);
+        let tool_main =
+            tools::get_tool_main(subcommand_name).expect("Clap should've validated tool name");
+        log::debug!("Delegating to {} with {:?}", subcommand_name, ext_args);
+        return tool_main(&ext_args);
+    }
 
     let max_k = config
         .value_of("lookahead")
